==> react-timer-wrapper-0.3.1.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cleanProps from 'clean-react-props';

var TimerWrapper = function (_Component) {
  _inherits(TimerWrapper, _Component);

  function TimerWrapper(props) {
    _classCallCheck(this, TimerWrapper);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      duration: props.duration,
      startTime: props.active ? Date.now() - props.time : null,
      time: props.time
    };

    _this.tick = _this.tick.bind(_this);
    return _this;
  }

  TimerWrapper.prototype.componentDidMount = function componentDidMount() {
    var _state = this.state,
        duration = _state.duration,
        startTime = _state.startTime,
        time = _state.time;
    var _props = this.props,
        active = _props.active,
        onStart = _props.onStart;


    if (active) {
      var progress = Math.max(0, Math.min(1, time / duration));

      onStart({
        duration: duration,
        progress: this.getProgress(time),
        time: time
      });

      this.animationFrame = requestAnimationFrame(this.tick);
    }
  };

  TimerWrapper.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var _this2 = this;

    var active = nextProps.active,
        duration = nextProps.duration,
        time = nextProps.time,
        onStart = nextProps.onStart,
        onStop = nextProps.onStop;


    if (active === this.props.active && time !== this.state.time) {
      var timeDiff = this.state.time - time;

      this.setState({
        startTime: this.state.startTime + timeDiff,
        time: this.state.time + timeDiff
      });
      return;
    }

    if (active !== this.props.active) {
      switch (active) {
        case true:
          var nextTime = duration !== null && this.state.time >= duration ? 0 : this.state.time;

          this.setState({
            startTime: Date.now() - nextTime,
            time: nextTime
          }, function () {
            onStart({
              duration: duration,
              progress: _this2.getProgress(nextTime),
              time: nextTime
            });

            _this2.animationFrame = requestAnimationFrame(_this2.tick);
          });
          break;

        case false:
          cancelAnimationFrame(this.animationFrame);

          onStop({
            duration: duration,
            progress: this.getProgress(this.state.time),
            time: this.state.time
          });
          break;
      }
    }
  };

  TimerWrapper.prototype.componentWillUnmount = function componentWillUnmount() {
    cancelAnimationFrame(this.animationFrame);
  };

  TimerWrapper.prototype.getProgress = function getProgress(time) {
    var duration = this.state.duration;


    if (!duration) {
      return null;
    }

    return Math.max(0, Math.min(1, time / duration));
  };

  TimerWrapper.prototype.tick = function tick() {
    var _this3 = this;

    var _props2 = this.props,
        duration = _props2.duration,
        loop = _props2.loop,
        time = _props2.time,
        onFinish = _props2.onFinish,
        onTimeUpdate = _props2.onTimeUpdate,
        onStart = _props2.onStart;
    var startTime = this.state.startTime;


    var nextTime = Date.now() - startTime;

    onTimeUpdate({
      duration: duration,
      progress: this.getProgress(nextTime),
      time: nextTime
    });

    this.setState({
      time: nextTime
    }, function () {
      if (duration !== null && nextTime >= duration) {
        onFinish({
          duration: duration,
          progress: _this3.getProgress(nextTime),
          time: nextTime
        });

        if (!loop) {
          cancelAnimationFrame(_this3.animationFrame);
          return;
        }

        nextTime = 0;
        onStart({
          duration: duration,
          progress: 0,
          time: nextTime
        });

        _this3.setState({
          startTime: Date.now()
        });
      }

      _this3.animationFrame = requestAnimationFrame(_this3.tick);
    });
  };

  TimerWrapper.prototype.render = function render() {
    var _props3 = this.props,
        children = _props3.children,
        component = _props3.component,
        duration = _props3.duration;
    var time = this.state.time;


    var progress = duration && time ? time / duration : 0;

    var clonedChildren = React.Children.toArray(children).map(function (child, childIndex) {
      return React.cloneElement(child, {
        duration: duration,
        time: time,
        progress: progress
      });
    });

    return React.createElement(component, _extends({}, cleanProps(this.props)), clonedChildren);
  };

  return TimerWrapper;
}(Component);

TimerWrapper.propTypes = {
  active: PropTypes.bool,
  component: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  duration: PropTypes.number,
  loop: PropTypes.bool,
  time: PropTypes.number,
  onFinish: PropTypes.func,
  onTimeUpdate: PropTypes.func,
  onStart: PropTypes.func
};

TimerWrapper.defaultProps = {
  active: false,
  component: 'div',
  duration: 10000,
  loop: false,
  time: 0,
  onFinish: function onFinish() {},
  onStart: function onStart() {},
  onStop: function onStop() {},
  onTimeUpdate: function onTimeUpdate() {}
};

export default TimerWrapper;

==> react-timer-wrapper-0.3.6.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cleanProps from 'clean-react-props';

var TimerWrapper = function (_Component) {
  _inherits(TimerWrapper, _Component);

  function TimerWrapper(props) {
    _classCallCheck(this, TimerWrapper);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {
      duration: props.duration,
      startTime: props.active ? Date.now() - props.time : null,
      time: props.time
    };

    _this.tick = _this.tick.bind(_this);
    return _this;
  }

  TimerWrapper.prototype.componentDidMount = function componentDidMount() {
    var _state = this.state,
        duration = _state.duration,
        startTime = _state.startTime,
        time = _state.time;
    var _props = this.props,
        active = _props.active,
        onStart = _props.onStart;


    if (active) {
      onStart({
        duration: duration,
        progress: this.getProgress(time),
        time: time
      });

      this.animationFrame = requestAnimationFrame(this.tick);
    }
  };

  TimerWrapper.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var _this2 = this;

    var active = nextProps.active,
        duration = nextProps.duration,
        time = nextProps.time,
        onStart = nextProps.onStart,
        onStop = nextProps.onStop;


    if (active === this.props.active && time !== this.props.time && time !== this.state.time) {
      var timeDiff = this.state.time - time;

      this.setState({
        startTime: this.state.startTime + timeDiff,
        time: this.state.time + timeDiff
      });
      return;
    }

    if (active !== this.props.active) {
      switch (active) {
        case true:
          var nextTime = duration !== null && this.state.time >= duration ? 0 : this.state.time;

          this.setState({
            startTime: Date.now() - nextTime,
            time: nextTime
          }, function () {
            onStart({
              duration: duration,
              progress: _this2.getProgress(nextTime),
              time: nextTime
            });

            _this2.animationFrame = requestAnimationFrame(_this2.tick);
          });
          break;

        case false:
          cancelAnimationFrame(this.animationFrame);

          onStop({
            duration: duration,
            progress: this.getProgress(this.state.time),
            time: this.state.time
          });
          break;
      }
    }
  };

  TimerWrapper.prototype.componentWillUnmount = function componentWillUnmount() {
    cancelAnimationFrame(this.animationFrame);
  };

  TimerWrapper.prototype.getProgress = function getProgress(time) {
    var duration = this.state.duration;


    if (!duration) {
      return 0;
    }

    return Math.max(0, Math.min(1, time / duration));
  };

  TimerWrapper.prototype.tick = function tick() {
    var _this3 = this;

    var _props2 = this.props,
        duration = _props2.duration,
        loop = _props2.loop,
        time = _props2.time,
        onFinish = _props2.onFinish,
        onTimeUpdate = _props2.onTimeUpdate,
        onStart = _props2.onStart;
    var startTime = this.state.startTime;


    var nextTime = Date.now() - startTime;

    this.setState({
      time: nextTime
    }, function () {
      onTimeUpdate({
        duration: duration,
        progress: _this3.getProgress(nextTime),
        time: nextTime
      });

      if (duration !== null && nextTime >= duration) {
        onFinish({
          duration: duration,
          progress: _this3.getProgress(nextTime),
          time: nextTime
        });

        if (!loop) {
          cancelAnimationFrame(_this3.animationFrame);
          return;
        }

        nextTime = 0;
        onStart({
          duration: duration,
          progress: 0,
          time: nextTime
        });

        _this3.setState({
          startTime: Date.now()
        });
      }

      _this3.animationFrame = requestAnimationFrame(_this3.tick);
    });
  };

  TimerWrapper.prototype.render = function render() {
    var _props3 = this.props,
        children = _props3.children,
        component = _props3.component,
        duration = _props3.duration;
    var time = this.state.time;


    var progress = duration && time ? time / duration : 0;

    var clonedChildren = React.Children.toArray(children).map(function (child, childIndex) {
      return React.cloneElement(child, {
        duration: duration,
        time: time,
        progress: progress
      });
    });

    return React.createElement(component, _extends({}, cleanProps(this.props)), clonedChildren);
  };

  return TimerWrapper;
}(Component);

TimerWrapper.propTypes = {
  active: PropTypes.bool,
  component: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  duration: PropTypes.number,
  loop: PropTypes.bool,
  time: PropTypes.number,
  onFinish: PropTypes.func,
  onTimeUpdate: PropTypes.func,
  onStart: PropTypes.func
};

TimerWrapper.defaultProps = {
  active: false,
  component: 'div',
  duration: 10000,
  loop: false,
  time: 0,
  onFinish: function onFinish() {},
  onStart: function onStart() {},
  onStop: function onStop() {},
  onTimeUpdate: function onTimeUpdate() {}
};

export default TimerWrapper;
